@@ -68,7 +68,7 @@ This will take an already created [Instance](https://docs.aws.amazon.com/AWSEC2/
 The associated exmaple includes two Stacks that can be created.
 
 * AMIExample - Deploys Instance and creates AMI from Instance
-* InstanceExmaple - Deplotys Instance from previously created AMI
+* InstanceExample - Deploys Instance from previously created AMI
 
 ### AMI Example
 
@@ -90,7 +90,7 @@ const baseInstance = new BaseInstance(this, 'Instance', {
 });
 ```
 
-The exmaple will create a VPC and Instance to be used to create the AMI. This instance contains a [cloud-init script](example/resources/base_install.sh):
+The example will create a VPC and Instance to be used to create the AMI. This instance contains a [cloud-init script](example/resources/base_install.sh):
 
 ```bash
 HOMEDIR=/home/ec2-user
@@ -106,7 +106,7 @@ echo "AMI Hostname: $LOCAL_HOSTNAME" >> /home/ec2-user/config.txt
 echo "AMI InstanceId: $INSTANCE_ID" >> /home/ec2-user/config.txt
 ```
 
-This will result in a file: `/home/ec2-user/config.txt` that contains the base instance information. This fille will be retained in the AMI.
+This will result in a file: `/home/ec2-user/config.txt` that contains the base instance information. This file will be retained in the AMI.
 
 ```
 AMI Hostname: ec2-54-152-127-245.compute-1.amazonaws.com
@@ -192,6 +192,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import constructs
@@ -212,7 +214,7 @@ class BlockDeviceMapping:
         self,
         *,
         device_name: typing.Optional[builtins.str] = None,
-        ebs: typing.Optional["Ebs"] = None,
+        ebs: typing.Optional[typing.Union["Ebs", typing.Dict[str, typing.Any]]] = None,
         no_device: typing.Optional[builtins.str] = None,
         virtual_name: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -224,6 +226,12 @@ class BlockDeviceMapping:
         '''
         if isinstance(ebs, dict):
             ebs = Ebs(**ebs)
+        if __debug__:
+            type_hints = typing.get_type_hints(BlockDeviceMapping.__init__)
+            check_type(argname="argument device_name", value=device_name, expected_type=type_hints["device_name"])
+            check_type(argname="argument ebs", value=ebs, expected_type=type_hints["ebs"])
+            check_type(argname="argument no_device", value=no_device, expected_type=type_hints["no_device"])
+            check_type(argname="argument virtual_name", value=virtual_name, expected_type=type_hints["virtual_name"])
         self._values: typing.Dict[str, typing.Any] = {}
         if device_name is not None:
             self._values["device_name"] = device_name
@@ -277,12 +285,12 @@ class CreateAMI(
         id: builtins.str,
         *,
         instance_id: builtins.str,
-        block_device_mappings: typing.Optional[typing.Sequence[BlockDeviceMapping]] = None,
+        block_device_mappings: typing.Optional[typing.Sequence[typing.Union[BlockDeviceMapping, typing.Dict[str, typing.Any]]]] = None,
         delete_ami: typing.Optional[builtins.bool] = None,
         delete_instance: typing.Optional[builtins.bool] = None,
         description: typing.Optional[builtins.str] = None,
         name: typing.Optional[builtins.str] = None,
-        tag_specifications: typing.Optional[typing.Sequence["TagSpecification"]] = None,
+        tag_specifications: typing.Optional[typing.Sequence[typing.Union["TagSpecification", typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -295,6 +303,10 @@ class CreateAMI(
         :param name: 
         :param tag_specifications: 
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CreateAMI.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CreateAMIProps(
             instance_id=instance_id,
             block_device_mappings=block_device_mappings,
@@ -307,12 +319,12 @@ class CreateAMI(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="imageId")
     def image_id(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "imageId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="imageName")
     def image_name(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "imageName"))
@@ -336,12 +348,12 @@ class CreateAMIProps:
         self,
         *,
         instance_id: builtins.str,
-        block_device_mappings: typing.Optional[typing.Sequence[BlockDeviceMapping]] = None,
+        block_device_mappings: typing.Optional[typing.Sequence[typing.Union[BlockDeviceMapping, typing.Dict[str, typing.Any]]]] = None,
         delete_ami: typing.Optional[builtins.bool] = None,
         delete_instance: typing.Optional[builtins.bool] = None,
         description: typing.Optional[builtins.str] = None,
         name: typing.Optional[builtins.str] = None,
-        tag_specifications: typing.Optional[typing.Sequence["TagSpecification"]] = None,
+        tag_specifications: typing.Optional[typing.Sequence[typing.Union["TagSpecification", typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param instance_id: 
@@ -352,6 +364,15 @@ class CreateAMIProps:
         :param name: 
         :param tag_specifications: 
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CreateAMIProps.__init__)
+            check_type(argname="argument instance_id", value=instance_id, expected_type=type_hints["instance_id"])
+            check_type(argname="argument block_device_mappings", value=block_device_mappings, expected_type=type_hints["block_device_mappings"])
+            check_type(argname="argument delete_ami", value=delete_ami, expected_type=type_hints["delete_ami"])
+            check_type(argname="argument delete_instance", value=delete_instance, expected_type=type_hints["delete_instance"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument tag_specifications", value=tag_specifications, expected_type=type_hints["tag_specifications"])
         self._values: typing.Dict[str, typing.Any] = {
             "instance_id": instance_id,
         }
@@ -456,6 +477,17 @@ class Ebs:
         :param volume_size: 
         :param volume_type: 
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Ebs.__init__)
+            check_type(argname="argument delete_on_termination", value=delete_on_termination, expected_type=type_hints["delete_on_termination"])
+            check_type(argname="argument encrypted", value=encrypted, expected_type=type_hints["encrypted"])
+            check_type(argname="argument iops", value=iops, expected_type=type_hints["iops"])
+            check_type(argname="argument kms_key_id", value=kms_key_id, expected_type=type_hints["kms_key_id"])
+            check_type(argname="argument outpost_arn", value=outpost_arn, expected_type=type_hints["outpost_arn"])
+            check_type(argname="argument snapshot_id", value=snapshot_id, expected_type=type_hints["snapshot_id"])
+            check_type(argname="argument throughput", value=throughput, expected_type=type_hints["throughput"])
+            check_type(argname="argument volume_size", value=volume_size, expected_type=type_hints["volume_size"])
+            check_type(argname="argument volume_type", value=volume_type, expected_type=type_hints["volume_type"])
         self._values: typing.Dict[str, typing.Any] = {}
         if delete_on_termination is not None:
             self._values["delete_on_termination"] = delete_on_termination
@@ -549,12 +581,16 @@ class TagSpecification:
         self,
         *,
         resource_type: typing.Optional[ResourceType] = None,
-        tags: typing.Optional[typing.Sequence["Tags"]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union["Tags", typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param resource_type: 
         :param tags: 
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(TagSpecification.__init__)
+            check_type(argname="argument resource_type", value=resource_type, expected_type=type_hints["resource_type"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
         self._values: typing.Dict[str, typing.Any] = {}
         if resource_type is not None:
             self._values["resource_type"] = resource_type
@@ -594,6 +630,10 @@ class Tags:
         :param key: 
         :param value: 
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Tags.__init__)
+            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         self._values: typing.Dict[str, typing.Any] = {
             "key": key,
             "value": value,
